@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2020 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2023 by Oleksandr Shneyder                         *
 *                              <o.shneyder@phoca-gmbh.de>                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -34,10 +34,10 @@
 #endif
 #endif
 
-InteractionDialog::InteractionDialog(QWidget* parent): SVGFrame(":/img/svg/passform.svg",
+InteractionDialog::InteractionDialog(ONMainWindow* mainw, QWidget* parent): SVGFrame(mainw->images_resource_path("/svg/passform.svg"),
             false,parent )
 {
-    mw=(ONMainWindow*)parent;
+    mw=mainw;
 
     if ( !mw->retMiniMode() )
         setFixedSize ( this->sizeHint().width(),this->sizeHint().height()*1.5 );
@@ -62,11 +62,7 @@ InteractionDialog::InteractionDialog(QWidget* parent): SVGFrame(":/img/svg/passf
 
     QFont fnt=this->font();
     if ( mw->retMiniMode() )
-#ifdef Q_WS_HILDON
-        fnt.setPointSize ( 10 );
-#else
         fnt.setPointSize ( 9 );
-#endif
     this->setFont ( fnt );
     this->hide();
 
