@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2020 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2023 by Oleksandr Shneyder                         *
 *                              <o.shneyder@phoca-gmbh.de>                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -308,28 +308,11 @@ ConfigDialog::ConfigDialog ( QWidget * parent,  Qt::WindowFlags f )
                                 "/32x32/edit_settings.png" ) ) );
     setWindowTitle ( tr ( "Settings" ) );
 
-#ifdef Q_WS_HILDON
-    QFont fnt=font();
-    fnt.setPointSize ( 10 );
-    setFont ( fnt );
-    QSize sz=ok->sizeHint();
-    sz.setWidth ( ( int ) ( sz.width() /1.5 ) );
-    sz.setHeight ( ( int ) ( sz.height() /1.5 ) );
-    ok->setFixedSize ( sz );
-    sz=cancel->sizeHint();
-    sz.setWidth ( ( int ) ( sz.width() ) );
-    sz.setHeight ( ( int ) ( sz.height() /1.5 ) );
-    cancel->setFixedSize ( sz );
-    clientSshPort->setFixedHeight (
-        int ( clientSshPort->sizeHint().height() *1.5 ) );
-    defaults->hide();
-#endif
-
     pwid=new PrintWidget ( this );
     tabWidg->addTab ( pwid,tr ( "Printing" ) );
 
 #if defined ( Q_OS_WIN) && defined (CFGCLIENT )
-    xsetWidg=new XSettingsWidget(this);
+    xsetWidg=new XSettingsWidget(( ONMainWindow* ) parent, this);
     tabWidg->addTab(xsetWidg, tr("X.Org Server settings"));
 #endif
 
