@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2020 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2023 by Oleksandr Shneyder                         *
 *                              <o.shneyder@phoca-gmbh.de>                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -35,7 +35,7 @@
 
 
 FolderButton::FolderButton ( ONMainWindow* mw,QWidget *parent, QString folderPath, QString folderName )
-    : SVGFrame ( ":/img/svg/folder.svg",false,parent )
+    : SVGFrame ( mw->images_resource_path("/svg/folder.svg"),false,parent )
 {
     QPalette pal=palette();
     pal.setColor ( QPalette::Active, QPalette::WindowText, QPalette::Mid );
@@ -52,11 +52,7 @@ FolderButton::FolderButton ( ONMainWindow* mw,QWidget *parent, QString folderPat
 
     QFont fnt=font();
     if ( mw->retMiniMode() )
-#ifdef Q_WS_HILDON
-        fnt.setPointSize ( 10 );
-#else
         fnt.setPointSize ( 9 );
-#endif
     setFont ( fnt );
     setFocusPolicy ( Qt::NoFocus );
     bool miniMode=mw->retMiniMode();
@@ -106,24 +102,25 @@ void FolderButton::loadIcon()
     else
         st= new X2goSettings( "sessions" );
 
-    QString sessIcon=":/img/icons/128x128/folder.png";
-    QPixmap* pix;
+    QPixmap* pix=new QPixmap();
 
     QString normPath=(path+"/"+name).split("/",QString::SkipEmptyParts).join("::");
-
-    QByteArray picture = QByteArray::fromBase64( st->setting()->value ( "icon_"+normPath,
-                       ( QVariant )QString()).toString().toLocal8Bit());
-    if(!picture.size())
+    QString picURL=st->setting()->value ( "icon_"+normPath, ( QVariant )QString()).toString();
+    if(picURL.indexOf("file://")!=-1)
     {
-        pix=new QPixmap( sessIcon );
+        //load icon from file URL
+        pix->load(picURL.replace("file://",""));
     }
     else
     {
-        pix=new QPixmap();
-        pix->loadFromData(picture);
+        pix->loadFromData(QByteArray::fromBase64( picURL.toLocal8Bit()));
+    }
+    if(pix->isNull())
+    {
+        //loading icon has failed, load default icon
+        pix->load(par->iconsPath("/128x128/folder.png"));
     }
     bool miniMode=par->retMiniMode();
-
     if ( !miniMode )
     {
         icon->setPixmap ( pix->scaled ( 64,64,Qt::IgnoreAspectRatio,
@@ -153,7 +150,7 @@ bool FolderButton::lessThen ( const FolderButton* b1,
 void FolderButton::mousePressEvent ( QMouseEvent * event )
 {
     SVGFrame::mousePressEvent ( event );
-    loadBg ( ":/img/svg/folder_grey.svg" );
+    loadBg ( par->images_resource_path("/svg/folder_grey.svg" ));
 }
 
 void FolderButton::mouseReleaseEvent ( QMouseEvent * event )
@@ -161,7 +158,7 @@ void FolderButton::mouseReleaseEvent ( QMouseEvent * event )
     SVGFrame::mouseReleaseEvent ( event );
     int x=event->x();
     int y=event->y();
-    loadBg ( ":/img/svg/folder.svg" );
+    loadBg (  par->images_resource_path("/svg/folder.svg"));
     if ( x>=0 && x< width() && y>=0 && y<height() )
         emit clicked();
 }
