@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2020 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2023 by Oleksandr Shneyder                         *
 *                              <o.shneyder@phoca-gmbh.de>                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -19,6 +19,7 @@
 #include <QNetworkAccessManager>
 #include <QUrl>
 #include <QNetworkRequest>
+#include <QNetworkDiskCache>
 #include <QNetworkReply>
 #include <QUuid>
 #include <QTextStream>
@@ -37,6 +38,8 @@
 #include <QTemporaryFile>
 #include <QInputDialog>
 #include "InteractionDialog.h"
+#include <QStatusBar>
+#include "version.h"
 
 
 HttpBrokerClient::HttpBrokerClient ( ONMainWindow* wnd, ConfigFile* cfg )
@@ -72,7 +75,12 @@ HttpBrokerClient::HttpBrokerClient ( ONMainWindow* wnd, ConfigFile* cfg )
             x2goDebug<<"Custom CA certificate file loaded into HTTPS broker client: "<<config->brokerCaCertFile;
         }
 
+        QDir dr;
+        dr.mkpath(mainWindow->getHomeDirectory()+"/.x2go");
         http=new QNetworkAccessManager ( this );
+        QNetworkDiskCache *cache = new QNetworkDiskCache(this);
+        cache->setCacheDirectory(mainWindow->getHomeDirectory()+"/.x2go/cache");
+        http->setCache(cache);
         x2goDebug<<"Setting up connection to broker: "<<config->brokerurl;
 
         connect ( http, SIGNAL ( sslErrors ( QNetworkReply*, const QList<QSslError>& ) ),this,
@@ -369,6 +377,13 @@ void HttpBrokerClient::sendEvent(const QString& ev, const QString& id, const QSt
     if(mainWindow->getUsePGPCard())
         brokerUser=mainWindow->getCardLogin();
 
+    QString os="linux";
+#ifdef Q_OS_WIN
+    os="windows";
+#endif
+#ifdef Q_OS_DARWIN
+    os="mac";
+#endif
     if(!sshBroker)
     {
         QString req;
@@ -385,6 +400,8 @@ void HttpBrokerClient::sendEvent(const QString& ev, const QString& id, const QSt
                              "display="<<QUrl::toPercentEncoding(display)<<"&"<<
                              "start="<<QUrl::toPercentEncoding(start)<<"&"<<
                              "elapsed="<<QString::number(connectionTime)<<"&"<<
+                             "version="<<QUrl::toPercentEncoding(VERSION)<<"&"<<
+                             "os="<<os<<"&"<<
                              "authid="<<nextAuthId;
         x2goDebug << "sending request: "<< scramblePwd(req.toUtf8());
         QNetworkRequest request(QUrl(config->brokerurl));
@@ -397,12 +414,12 @@ void HttpBrokerClient::sendEvent(const QString& ev, const QString& id, const QSt
         if (nextAuthId.length() > 0) {
             sshConnection->executeCommand ( config->sshBrokerBin+" --user "+ brokerUser +" --authid "+nextAuthId+
             " --task clientevent --sid \""+id+"\" --event "+ev+" --server \""+server+"\" --client \""+client+"\" --login "+"\""+
-            login+"\" --cmd \""+cmd+"\" --display \""+display+"\" --start \""+start+"\" --elapsed "+QString::number(connectionTime),
+            login+"\" --cmd \""+cmd+"\" --display \""+display+"\" --start \""+start+"\" --elapsed "+QString::number(connectionTime)+" --version \""+VERSION+"\" --os "+os,
             this,SLOT ( slotEventSent(bool,QString,int)));
         } else {
             sshConnection->executeCommand ( config->sshBrokerBin+" --user "+ brokerUser +
             " --task clientevent --sid \""+id+"\" --event "+ev+" --server \""+server+"\" --client \""+client+"\" --login "+"\""+
-            login+"\" --cmd \""+cmd+"\" --display \""+display+"\" --start \""+start+"\" --elapsed "+QString::number(connectionTime),
+            login+"\" --cmd \""+cmd+"\" --display \""+display+"\" --start \""+start+"\" --elapsed "+QString::number(connectionTime)+" --version \""+VERSION+"\" --os "+os,
             this,SLOT ( slotEventSent(bool,QString,int)));
         }
     }
@@ -414,12 +431,14 @@ void HttpBrokerClient::slotEventSent(bool success, QString answer, int)
     if(!success)
     {
         x2goDebug<<answer;
+        mainWindow->setBrokerStatus(tr("Disconnected from broker: ")+answer, true);
         QMessageBox::critical(0,tr("Error"),answer);
         emit fatalHttpError();
         return;
     }
     if(!checkAccess(answer))
         return;
+    mainWindow->setBrokerStatus(tr("Connected to broker"));
     x2goDebug<<"event sent:"<<answer;
     if(answer.indexOf("SUSPEND")!=-1)
     {
@@ -498,7 +517,8 @@ void HttpBrokerClient::processClientConfig(const QString& raw_content)
 {
     X2goSettings st(raw_content, QSettings::IniFormat);
     mainWindow->config.brokerEvents=st.setting()->value("events",false).toBool();
-    mainWindow->config.brokerLiveEventsTimeout=st.setting()->value("liveevent",false).toUInt();
+    mainWindow->config.brokerLiveEventsTimeout=st.setting()->value("liveevent",0).toUInt();
+    mainWindow->config.brokerSyncTimeout=st.setting()->value("syncinterval",0).toUInt();
     if(mainWindow->config.brokerEvents)
     {
         x2goDebug<<"sending client events to broker";
@@ -507,6 +527,10 @@ void HttpBrokerClient::processClientConfig(const QString& raw_content)
             x2goDebug<<"sending alive events to broker every "<<mainWindow->config.brokerLiveEventsTimeout<<" seconds";
         }
     }
+    if(mainWindow->config.brokerSyncTimeout)
+    {
+        x2goDebug<<"synchronizing with broker every "<<mainWindow->config.brokerSyncTimeout<<" seconds";
+    }
 }
 
 
@@ -515,7 +539,7 @@ void HttpBrokerClient::createIniFile(const QString& raw_content)
     QString content;
     content = raw_content;
     content.replace("<br>","\n");
-    x2goDebug<<"Inifile content: "<<content<<endl;
+//     x2goDebug<<"Inifile content: "<<content<<endl;
     QString cont;
     QStringList lines=content.split("START_USER_SESSIONS\n");
     if (lines.count()>1)
@@ -523,7 +547,39 @@ void HttpBrokerClient::createIniFile(const QString& raw_content)
         cont=lines[1];
         cont=cont.split("END_USER_SESSIONS\n")[0];
     }
-    mainWindow->config.iniFile=cont;
+
+    if(!sshBroker)
+    {
+        QStringList iniLines=cont.split("\n");
+        cont.clear();
+        clearResRequests();
+        //check if some of the icon or icon_foldername values are URLs and need to be downloaded
+        foreach(QString ln, iniLines)
+        {
+            ln=ln.trimmed();
+            if(ln.indexOf("icon")==0)
+            {
+                QStringList lnParts=ln.split("=");
+                QString iconUrl=lnParts.last().trimmed();
+                if((iconUrl.indexOf("http://")!=-1)||(iconUrl.indexOf("https://")!=-1))
+                {
+                    ln=lnParts[0]+"=file://"+getResource(iconUrl);
+                }
+            }
+            cont+=ln+"\n";
+        }
+        mainWindow->config.iniFile=cont;
+        if(resReplies.count()==0)
+        {
+            //we didn't request any resources, all session info is loaded
+            emit sessionsLoaded();
+        }
+    }
+    else
+    {
+        mainWindow->config.iniFile=cont;
+        emit sessionsLoaded();
+    }
     lines=content.split("START_CLIENT_CONFIG\n");
     if (lines.count()>1)
     {
@@ -538,9 +594,55 @@ void HttpBrokerClient::createIniFile(const QString& raw_content)
 }
 
 
+//get the fname on disk from resource URL
+QString HttpBrokerClient::resourceFname(const QUrl& url)
+{
+    QString fname=url.toString();
+    fname.replace("http://","");
+    fname.replace("https://","");
+    fname.replace("/","_");
+    QDir dr;
+    dr.mkdir(mainWindow->getHomeDirectory()+"/.x2go/res");
+    return mainWindow->getHomeDirectory()+"/.x2go/res/"+fname;
+}
+
+//return true if the URL is already requested
+bool HttpBrokerClient::isResRequested(const QUrl& url)
+{
+    foreach(QNetworkReply* reply, resReplies)
+    {
+        if(reply->url().toString()==url.toString())
+        {
+            return true;
+        }
+    }
+    return false;
+}
+
+//download resource if needed and return the name on the disk
+QString HttpBrokerClient::getResource(QString resURL)
+{
+    QUrl url(resURL);
+    if(!isResRequested(url))
+    {
+        resReplies << http->get(QNetworkRequest(url));
+    }
+    return resourceFname(url);
+}
+
+//clear list of res requests
+void HttpBrokerClient::clearResRequests()
+{
+    foreach(QNetworkReply* reply, resReplies)
+    {
+        reply->deleteLater();
+    }
+    resReplies.clear();
+}
+
 bool HttpBrokerClient::checkAccess(QString answer )
 {
-    x2goDebug<<"Called checkAccess - answer was: "<<answer;
+//     x2goDebug<<"Called checkAccess - answer was: "<<answer;
     if (answer.indexOf("Access granted")==-1)
     {
         QMessageBox::critical (
@@ -591,10 +693,13 @@ void HttpBrokerClient::slotListSessions(bool success, QString answer, int)
         emit fatalHttpError();
         return;
     }
+
     if(!checkAccess(answer))
         return;
+
+    mainWindow->setBrokerStatus(tr("Connected to broker"));
+
     createIniFile(answer);
-    emit sessionsLoaded();
 }
 
 void HttpBrokerClient::slotPassChanged(bool success, QString answer, int)
@@ -629,13 +734,41 @@ void HttpBrokerClient::slotSelectSession(bool success, QString answer, int)
 
 void HttpBrokerClient::slotRequestFinished ( QNetworkReply*  reply )
 {
+    if(resReplies.indexOf(reply) != -1)
+    {
+        if(reply->error() != QNetworkReply::NoError)
+        {
+            x2goDebug<<"Download request for "<<reply->url().toString()<< " failed with error: "<<reply->errorString();
+        }
+        else
+        {
+//             x2goDebug<<"saving to "<<resourceFname(reply->url().toString())<<" from cache: "<<reply->attribute(QNetworkRequest::SourceIsFromCacheAttribute).toBool();
+            QFile file(resourceFname(reply->url().toString()));
+            file.open(QIODevice::WriteOnly);
+            file.write(reply->readAll());
+            file.close();
+        }
+        foreach(QNetworkReply* r, resReplies)
+        {
+            if(!r->isFinished())
+            {
+                return;
+            }
+        }
+        emit sessionsLoaded();
+        return;
+    }
     if(reply->error() != QNetworkReply::NoError)
     {
         x2goDebug<<"Broker HTTP request failed with error: "<<reply->errorString();
-        if(reply == eventRequest)
+        mainWindow->setBrokerStatus(tr("Disconnected from broker: ")+reply->errorString(), true);
+        if(reply == eventRequest || reply == sessionsRequest)
         {
             reply->deleteLater();
-            eventRequest=0l;
+            if(reply == eventRequest)
+                eventRequest=0l;
+            else
+                sessionsRequest=0l;
             //do not exit, just return the function
             return;
         }
@@ -645,7 +778,7 @@ void HttpBrokerClient::slotRequestFinished ( QNetworkReply*  reply )
     }
 
     QString answer ( reply->readAll() );
-    x2goDebug<<"A http request returned. Result was: "<<answer;
+//     x2goDebug<<"A http request returned. Result was: "<<answer;
     if (reply == testConRequest)
     {
         testConRequest=0l;
@@ -672,6 +805,7 @@ void HttpBrokerClient::slotRequestFinished ( QNetworkReply*  reply )
         slotEventSent(true,answer,0);
     }
 
+
     // We receive ownership of the reply object
     // and therefore need to handle deletion.
     reply->deleteLater();
@@ -686,6 +820,8 @@ void HttpBrokerClient::parseSession(QString sinfo)
     int keyStartPos=sinfo.indexOf("-----BEGIN DSA PRIVATE KEY-----");
     if(keyStartPos==-1)
         keyStartPos=sinfo.indexOf("-----BEGIN RSA PRIVATE KEY-----");
+    if(keyStartPos==-1)
+        keyStartPos=sinfo.indexOf("-----BEGIN OPENSSH PRIVATE KEY-----");
     QString endStr="-----END DSA PRIVATE KEY-----";
     int keyEndPos=sinfo.indexOf(endStr);
     if(keyEndPos==-1)
@@ -693,8 +829,16 @@ void HttpBrokerClient::parseSession(QString sinfo)
         endStr="-----END RSA PRIVATE KEY-----";
         keyEndPos=sinfo.indexOf(endStr);
     }
+    if(keyEndPos==-1)
+    {
+        endStr="-----END OPENSSH PRIVATE KEY-----";
+        keyEndPos=sinfo.indexOf(endStr);
+    }
     if (! (keyEndPos == -1 || keyStartPos == -1 || lst.size()==0))
+    {
+        x2goDebug<<"Found key for authentication";
         config->key=sinfo.mid(keyStartPos, keyEndPos+endStr.length()-keyStartPos);
+    }
     QString serverLine=(lst[1].split("\n"))[0];
     QStringList words=serverLine.split(":",QString::SkipEmptyParts);
     config->serverIp=words[0];
