@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2020 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2023 by Oleksandr Shneyder                         *
 *                              <o.shneyder@phoca-gmbh.de>                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -77,8 +77,10 @@ class HttpBrokerClient;
 class QMenu;
 class QComboBox;
 class InteractionDialog;
-
+class QNetworkAccessManager;
+class QNetworkReply;
 class SessionExplorer;
+class QSplashScreen;
 struct user
 {
     int uin;
@@ -151,7 +153,7 @@ struct x2goSession
     bool published;
     int colorDepth;
     bool fullscreen;
-    enum {DESKTOP,ROOTLESS,SHADOW, KDRIVE} sessionType;
+    enum {DESKTOP,ROOTLESS,SHADOW, KDRIVE, ROOTLESSKDRIVE} sessionType;
     QString command;
     void operator = ( const x2goSession& s );
 };
@@ -172,6 +174,7 @@ struct ConfigFile
     bool brokerKrbLogin;
     bool brokerEvents; //Send events to broker and get control commands
     uint brokerLiveEventsTimeout; //(seconds)How often send alive events, 0 - do not send
+    uint brokerSyncTimeout; //(seconds)How often synchronize with broker, 0 - not synchronize
     QString brokerSshKey;
     QString brokerCaCertFile;
     QString iniFile;
@@ -544,6 +547,7 @@ public:
     SshMasterConnection* findServerSshConnection(QString host);
     void cleanServerSshConnections();
 
+    bool parseResourceUrl(const QString& url);
     void showHelp();
     void showVersion();
     void showTextFile(QString file, QString title);
@@ -568,6 +572,9 @@ public:
     void setEmbedSessionActionsEnabled ( bool enable );
     bool startSshd (key_types key_type = RSA_KEY_TYPE);
     QSize getEmbedAreaSize();
+    void setBrokerStatus(const QString& text, bool error=false);
+    bool isPassFormHidden();
+    bool isSelectFormHidden();
 #ifdef Q_OS_WIN
     static QString cygwinPath ( const QString& winPath );
     void startXOrg(std::size_t start_offset = 0);
@@ -594,6 +601,8 @@ private:
     bool startMaximized;
     bool closeDisconnect;
     bool startHidden;
+    QString splashPix;
+    QSplashScreen* splash;
     bool keepTrayIcon;
     bool hideFolderSharing;
     bool brokerNoauthWithSessionUsername;
@@ -632,6 +641,10 @@ private:
     QString sshPort;
     QString clientSshPort;
     QString defaultSshPort;
+    QString resourceDir;
+    QString resourceURL;
+    QDir* resourceTmpDir;
+    QList<QNetworkReply*> resReply;
 #ifdef Q_OS_WIN
     QString sshLog;
 #endif
@@ -672,6 +685,7 @@ private:
 
 
     QLabel* selectSessionLabel;
+    QLabel* running_label;
     SessTreeView* sessTv;
 
     QLineEdit* desktopFilter;
@@ -731,6 +745,7 @@ private:
     QTimer *proxyWinTimer;
     QTimer *xineramaTimer;
     QTimer *brokerAliveTimer;
+    QTimer *brokerSyncTimer;
     short xinSizeInc;
     QRect lastDisplayGeometry;
     QList <QRect> xineramaScreens;
@@ -823,6 +838,8 @@ private:
     QAction *act_new;
     QAction *act_sessicon;
     QProcess *nxproxy;
+    int proxyWinWidth;
+    int proxyWinHeight;
 #ifndef Q_OS_WIN
     QProcess *sshd;
 #else
@@ -841,8 +858,6 @@ private:
     bool cyEntry;
 
     bool maximizeProxyWin;
-    int proxyWinWidth;
-    int proxyWinHeight;
     QTimer* xorgLogTimer;
     QString xorgLogFile;
     QMutex xorgLogMutex;
@@ -917,6 +932,8 @@ private:
     bool trayMinCon;
     bool trayMaxDiscon;
     bool trayAutoHidden;
+    bool resourcesLoaded;
+    QNetworkAccessManager* resourceLoader;
 
     //server connection type
     // DEFAULT - start X2GO session
@@ -928,6 +945,9 @@ private:
     QString suspendTerminateHostFromBroker;
     QString suspendTerminateSessionFromBroker;
 
+    void initUI();
+    void initSplash();
+    void destroySplash();
     void sendEventToBroker(client_events ev);
     void suspendFromBroker(const QString& sid);
     void terminateFromBroker(const QString& sid);
@@ -984,7 +1004,6 @@ private:
     void plugAppsInTray();
     QMenu* initTrayAppMenu(QString text, QPixmap icon);
     void setTrayIconToSessionIcon(QString info);
-
     /*
      * Tries to get the most suitable translator for the running system.
      *
@@ -1003,6 +1022,7 @@ private:
      * translation.
      */
     static bool get_translator (const QString file_name_start, QTranslator **translator);
+    void getClientKeyboardConfig(QString& layout, QString& model, QString& variant);
 
 
 protected:
@@ -1039,7 +1059,6 @@ private slots:
     void readUsers();
     void slotSelectedFromList ( UserButton* user );
     void slotUnameEntered();
-    void slotClosePass();
     void slotReadSessions();
     void slotManage();
     void displayToolBar ( bool );
@@ -1060,6 +1079,8 @@ private slots:
     void slotShutdownThinClient();
     void slotBrokerLogoutButton ();
     void slotReadApplications(bool result, QString output, int pid );
+    void slotResLoadRequestFinished( QNetworkReply*  reply );
+    void setProxyWinNotResizable();
 
 public slots:
     void slotConfig();
@@ -1069,6 +1090,8 @@ public slots:
     void slotActivateWindow();
     void setFocus();
     void slotEnableBrokerLogoutButton ();
+    void slotClosePass();
+    void slotCloseSelectDlg();
 
 private slots:
     void slotSendBrokerAlive();
@@ -1076,7 +1099,6 @@ private slots:
     void slotSnameChanged ( const QString& );
     void slotSelectedFromList ( SessionButton* session );
     void slotSessEnter();
-    void slotCloseSelectDlg();
     void slotActivated ( const QModelIndex& index );
     void slotResumeSess();
     void slotSuspendSess();
