@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2020 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2023 by Oleksandr Shneyder                         *
 *                              <o.shneyder@phoca-gmbh.de>                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -40,7 +40,7 @@
 #include <QVBoxLayout>
 #include <QHBoxLayout>
 #include <QFile>
-
+#include <QSplashScreen>
 #include "httpbrokerclient.h"
 #include <QTimer>
 #include <QComboBox>
@@ -72,6 +72,9 @@
 #include <QLocalSocket>
 #if QT_VERSION < 0x050000
 #include <QPlastiqueStyle>
+#else
+#include <QGuiApplication>
+#include <QScreen>
 #endif
 #include "imgframe.h"
 #include <QToolTip>
