@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2020 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2023 by Oleksandr Shneyder                         *
 *                              <o.shneyder@phoca-gmbh.de>                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -42,10 +42,11 @@
 
 
 SessionButton::SessionButton ( ONMainWindow* mw,QWidget *parent, QString id )
-    : SVGFrame ( ":/img/svg/sessionbut.svg",false,parent )
+    : SVGFrame ( mw->images_resource_path("/svg/sessionbut.svg"),false,parent )
 {
     editable=mw->sessionEditEnabled();
 
+    running=suspended=0;
 
     QPalette pal=palette();
     pal.setColor ( QPalette::Active, QPalette::WindowText, QPalette::Mid );
@@ -57,15 +58,12 @@ SessionButton::SessionButton ( ONMainWindow* mw,QWidget *parent, QString id )
 
     setPalette(pal);
 
-
+    updated=false;
+    fav=false;
 
     QFont fnt=font();
     if ( mw->retMiniMode() )
-#ifdef Q_WS_HILDON
-        fnt.setPointSize ( 10 );
-#else
         fnt.setPointSize ( 9 );
-#endif
     setFont ( fnt );
     setFocusPolicy ( Qt::NoFocus );
     bool miniMode=mw->retMiniMode();
@@ -98,6 +96,12 @@ SessionButton::SessionButton ( ONMainWindow* mw,QWidget *parent, QString id )
     geomBox->update();
     geomBox->setPalette ( cpal );
 
+    pathLabel=new QLabel ( this );
+    QFont lfnt=fnt;
+    lfnt.setWeight(0);
+    lfnt.setPointSize(lfnt.pointSize()-2);
+    pathLabel->setFont(lfnt);
+
     sessName=new QLabel ( this );
     sessStatus=new QLabel ( this );
     fnt=sessName->font();
@@ -145,6 +149,15 @@ SessionButton::SessionButton ( ONMainWindow* mw,QWidget *parent, QString id )
     editBut->setPalette ( cpal );
     sessMenu=new QMenu ( this );
 
+
+    favButton=new QPushButton (this);
+    favButton->setIcon(QIcon(mw->iconsPath ( "/16x16/fav.png" )));
+    favButton->setFlat(true);
+    favButton->setFixedSize(24,24);
+    favButton->setMouseTracking(true);
+    favButton->setPalette ( cpal );
+    connect( favButton, SIGNAL(clicked()), this, SLOT(slotFavClick()));
+
     connect ( sessMenu,SIGNAL ( aboutToHide() ),this,
               SLOT ( slotMenuHide() ) );
 
@@ -152,7 +165,7 @@ SessionButton::SessionButton ( ONMainWindow* mw,QWidget *parent, QString id )
                  QIcon (
                      mw->iconsPath ( "/16x16/edit.png" ) ),
                  tr ( "Session preferences ..." ) );
-#if (!defined Q_WS_HILDON) && (!defined Q_OS_DARWIN)
+#if (!defined Q_OS_DARWIN)
     act_createIcon=sessMenu->addAction (
                        QIcon ( mw->iconsPath ( "/16x16/create_file.png" ) ),
                        tr (
@@ -168,12 +181,13 @@ SessionButton::SessionButton ( ONMainWindow* mw,QWidget *parent, QString id )
 
     connect ( act_remove,SIGNAL ( triggered ( bool ) ),this,
               SLOT ( slotRemove() ) );
-#if (!defined Q_WS_HILDON) && (!defined Q_OS_DARWIN)
+#if (!defined Q_OS_DARWIN)
     connect ( act_createIcon,SIGNAL ( triggered ( bool ) ),this,
               SLOT ( slotCreateSessionIcon() ) );
 #endif
 
     editBut->setToolTip ( tr ( "Session actions" ) );
+    favButton->setToolTip(tr("Add to favorites"));
     cmdBox->setToolTip ( tr ( "Select type" ) );
 
     geomBox->setToolTip ( tr ( "Select resolution" ) );
@@ -182,9 +196,12 @@ SessionButton::SessionButton ( ONMainWindow* mw,QWidget *parent, QString id )
 
     if ( !miniMode )
     {
+        pathLabel->move(80,10);
+        pathLabel->setMaximumWidth(224);
         sessName->move ( 80,34 );
         sessStatus->move(80,50);
         editBut->move ( 307,156 );
+        favButton->move ( 307,10 );
         serverIcon->move ( 58,84 );
         server->move ( 80,84 );
         cmdIcon->move ( 58,108 );
@@ -198,9 +215,11 @@ SessionButton::SessionButton ( ONMainWindow* mw,QWidget *parent, QString id )
     }
     else
     {
+        pathLabel->move(64,6);
+        pathLabel->setMaximumWidth(154);
         editBut->move ( 218,113 );
-        sessName->move ( 64,11 );
-        sessStatus->hide();
+        favButton->move ( 218,10 );
+        sessName->move ( 64,22 );
         serverIcon->move ( 66,44 );
         server->move ( 88,44 );
         cmdIcon->move ( 66,68 );
@@ -215,9 +234,15 @@ SessionButton::SessionButton ( ONMainWindow* mw,QWidget *parent, QString id )
 
     if (mw->brokerMode)
     {
+        pathLabel->move(10,10);
+        if(miniMode)
+            pathLabel->setMaximumWidth(204);
+        else
+            pathLabel->setMaximumWidth(294);
         icon->move(10,30);
         sessName->move(90,50);
         sessStatus->move(90,70);
+        sessStatus->setMinimumWidth(220);
         setFixedHeight(120);
     }
 
@@ -246,6 +271,7 @@ SessionButton::SessionButton ( ONMainWindow* mw,QWidget *parent, QString id )
               SLOT ( slot_geom_change ( const QString& ) ) );
 
     editBut->setFocusPolicy ( Qt::NoFocus );
+    favButton->setFocusPolicy ( Qt::NoFocus );
     sound->setFocusPolicy ( Qt::NoFocus );
     cmdBox->setFocusPolicy ( Qt::NoFocus );
     geomBox->setFocusPolicy ( Qt::NoFocus );
@@ -275,6 +301,52 @@ SessionButton::SessionButton ( ONMainWindow* mw,QWidget *parent, QString id )
 SessionButton::~SessionButton()
 {}
 
+bool SessionButton::getFavFromConfig()
+{
+    X2goSettings st( "favorits" );
+    return st.setting()->value("favorites").toStringList().contains(sid);
+}
+
+void SessionButton::slotFavClick()
+{
+    setFav(!fav);
+    X2goSettings st( "favorits" );
+    QStringList favs=st.setting()->value("favorites").toStringList();
+    if(fav)
+    {
+        if(! favs.contains(sid))
+        {
+            favs.append(sid);
+            st.setting()->setValue("favorites",favs);
+        }
+    }
+    else
+    {
+        if(favs.contains(sid))
+        {
+            favs.removeAll(sid);
+            st.setting()->setValue("favorites",favs);
+        }
+    }
+    st.setting()->sync();
+    emit favClicked();
+}
+
+void SessionButton::setFav(bool fav)
+{
+    this->fav=fav;
+    if(fav)
+    {
+        favButton->setIcon(QIcon(par->iconsPath ( "/16x16/fav1.png" )));
+        favButton->setToolTip(tr("Remove from favorites"));
+    }
+    else
+    {
+        favButton->setIcon(QIcon(par->iconsPath ( "/16x16/fav.png" )));
+        favButton->setToolTip(tr("Add to favorites"));
+    }
+}
+
 void SessionButton::slotClicked()
 {
     emit sessionSelected ( this );
@@ -293,8 +365,11 @@ void SessionButton::slotRemove()
 
 void SessionButton::redraw()
 {
+
+    updated=true;
     bool snd;
 
+    QStringList toolTip;
 
     X2goSettings *st;
 
@@ -313,6 +388,10 @@ void SessionButton::redraw()
         name=tails.last();
         tails.pop_back();
         path=tails.join("/");
+        if(path.length())
+        {
+            toolTip<<path;
+        }
     }
 
     QFontMetrics metr(sessName->font());
@@ -322,6 +401,7 @@ void SessionButton::redraw()
     sessName->setText (elName);
     sessName->setToolTip(nameofSession);
 
+    sessStatus->setText("");
     QString status=st->setting()->value ( sid+"/status",
                                           ( QVariant ) QString::null ).toString();
     if (status == "R")
@@ -333,10 +413,10 @@ void SessionButton::redraw()
         sessStatus->setText("("+tr("suspended")+")");
     }
 
-    int suspended=st->setting()->value ( sid+"/suspended",
+    suspended=st->setting()->value ( sid+"/suspended",
                                          ( QVariant ) QString::null ).toUInt();
 
-    int running=st->setting()->value ( sid+"/running",
+    running=st->setting()->value ( sid+"/running",
                                          ( QVariant ) QString::null ).toUInt();
     if(suspended || running)
     {
@@ -353,18 +433,33 @@ void SessionButton::redraw()
     }
 
     QString sessIcon = wrap_legacy_resource_URIs (st->setting()->value (sid+"/icon",
-                       (QVariant) ":/img/icons/128x128/x2gosession.png"
+                       (QVariant) par->iconsPath("/128x128/x2gosession.png")
                                                                        ).toString ());
     sessIcon = expandHome(sessIcon);
     QPixmap* pix;
 
-    x2goDebug << "Creating QPixmap with session icon: " << sessIcon.toLatin1 () << ".";
-    if (!par->brokerMode || sessIcon == ":/img/icons/128x128/x2gosession.png")
+    if(sessIcon == ":/img/icons/128x128/x2gosession.png")
+    {
+        sessIcon=par->iconsPath("/128x128/x2gosession.png");
+    }
+//     x2goDebug << "Creating QPixmap with session icon: " << sessIcon.toLatin1 () << ".";
+    if (!par->brokerMode || sessIcon == par->iconsPath("/128x128/x2gosession.png"))
         pix=new QPixmap( sessIcon );
     else
     {
         pix=new QPixmap;
-        pix->loadFromData(QByteArray::fromBase64(sessIcon.toLatin1()));
+        if(sessIcon.indexOf("file://")!=-1)
+        {
+            //load icon from file URL
+            pix->load(sessIcon.replace("file://",""));
+        }
+        else
+            pix->loadFromData(QByteArray::fromBase64(sessIcon.toLatin1()));
+        if(pix->isNull())
+        {
+            //loading icon has failed, load default icon
+            pix->load(par->iconsPath("/128x128/x2gosession.png"));
+        }
     }
     if ( !par->retMiniMode() )
         icon->setPixmap ( pix->scaled ( 64,64,Qt::IgnoreAspectRatio,
@@ -390,6 +485,7 @@ void SessionButton::redraw()
     published=st->setting()->value ( sid+"/published",
                                      false ).toBool();
 
+    toolTip<<uname+"@"+sv;
 
     cmdBox->clear();
     cmdBox->addItem ( "KDE" );
@@ -522,6 +618,7 @@ void SessionButton::redraw()
     cmdIcon->setPixmap ( cmdpix );
     cmd->setText ( command );
 
+    toolTip<<command;
 
     geomBox->clear();
     geomBox->addItem ( tr ( "fullscreen" ) );
@@ -536,16 +633,12 @@ void SessionButton::redraw()
 
 
         }
-#ifndef Q_WS_HILDON
 
 
     geomBox->addItem ( "1440x900" );
     geomBox->addItem ( "1280x1024" );
     geomBox->addItem ( "1024x768" );
     geomBox->addItem ( "800x600" );
-#else
-    geomBox->addItem ( tr ( "window" ) );
-#endif
     if ( st->setting()->value ( sid+"/fullscreen",
                                 ( QVariant ) false ).toBool() )
     {
@@ -573,7 +666,6 @@ void SessionButton::redraw()
     }
     else
     {
-#ifndef	Q_WS_HILDON
         QString g=QString::number ( st->setting()->value (
                                         sid+"/width" ).toInt() );
         g+="x"+QString::number ( st->setting()->value (
@@ -582,10 +674,6 @@ void SessionButton::redraw()
         if ( geomBox->findText ( g ) ==-1 )
             geomBox->addItem ( g );
         geomBox->setCurrentIndex ( geomBox->findText ( g ) );
-#else
-        geom->setText ( tr ( "window" ) );
-        geomBox->setCurrentIndex ( 1 );
-#endif
     }
 
     if (directRDP)
@@ -617,18 +705,20 @@ void SessionButton::redraw()
     cmd->setMinimumSize ( cmd->sizeHint() );
     server->setMinimumSize ( server->sizeHint() );
     delete st;
+    setFav(getFavFromConfig());
+    setToolTip(toolTip.join("\n"));
 }
 
 void SessionButton::mousePressEvent ( QMouseEvent * event )
 {
     SVGFrame::mousePressEvent ( event );
-    loadBg ( ":/img/svg/sessionbut_grey.svg" );
+    loadBg ( par->images_resource_path("/svg/sessionbut_grey.svg" ));
 }
 
 void SessionButton::mouseReleaseEvent ( QMouseEvent * event )
 {
     SVGFrame::mouseReleaseEvent ( event );
-    loadBg ( ":/img/svg/sessionbut.svg" );
+    loadBg ( par->images_resource_path("/svg/sessionbut.svg" ));
 
     QPoint click_pos (event->x (), event->y ());
 
@@ -685,6 +775,23 @@ void SessionButton::mouseMoveEvent ( QMouseEvent * event )
 {
 
     SVGFrame::mouseMoveEvent ( event );
+    if ( favButton->isFlat() )
+    {
+        if ( event->x() > favButton->x() && event->x() < favButton->x() +
+            favButton->width() &&
+            event->y() >favButton->y() && event->y() <favButton->y() +
+            favButton->height() )
+            favButton->setFlat ( false );
+    }
+    else
+    {
+        if ( event->x() < favButton->x() || event->x() > favButton->x() +
+            favButton->width() ||
+            event->y() <favButton->y() || event->y() >favButton->y() +
+            favButton->height() )
+            favButton->setFlat ( true );
+    }
+
     if (!editable)
         return;
     if ( cmd->isVisible() )
@@ -966,9 +1073,6 @@ void SessionButton::slot_geom_change ( const QString& new_g )
     else
     {
         QString new_geom=new_g;
-#ifdef Q_WS_HILDON
-        new_geom="800x600";
-#endif
         st.setting()->setValue ( sid+"/fullscreen", ( QVariant ) false );
         st.setting()->setValue ( sid+"/multidisp", ( QVariant ) false );
         st.setting()->setValue ( sid+"/maxdim", ( QVariant ) false );
@@ -982,8 +1086,8 @@ void SessionButton::slot_geom_change ( const QString& new_g )
 bool SessionButton::lessThen ( const SessionButton* b1,
                                const SessionButton* b2 )
 {
-    return b1->sessName->text().toLower().localeAwareCompare (
-               b2->sessName->text().toLower() ) <0;
+    return (b1->path+"/"+b1->sessName->text()).toLower().localeAwareCompare (
+               (b2->path+"/"+b2->sessName->text()).toLower() ) <0;
 }
 
 QString SessionButton::name()
@@ -1004,6 +1108,12 @@ void SessionButton::slotShowMenu()
                                     editBut->y() +editBut->height() ) ) );
 }
 
+void SessionButton::showAdvInfo(bool show)
+{
+    pathLabel->setText(path);
+    pathLabel->setVisible((show && path.length()));
+}
+
 
 void SessionButton::slotCreateSessionIcon()
 {
