@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2020 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2023 by Oleksandr Shneyder                         *
 *                              <o.shneyder@phoca-gmbh.de>                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -33,11 +33,28 @@
 #include "x2gologdebug.h"
 #include <QBuffer>
 #include <QDir>
+#include <QPushButton>
 
 SessionExplorer::SessionExplorer(ONMainWindow* p):QObject(p)
 {
     parent=p;
     lastSession=0;
+    initUpdate=true;
+    viewMode=ALL;
+    runButton=new QPushButton(tr("Running"),parent->getCentralFrame());
+    favButton=new QPushButton(tr("Favorites"),parent->getCentralFrame());
+    allButton=new QPushButton(tr("All Sessions"),parent->getCentralFrame());
+    runButton->hide();
+    allButton->hide();
+    favButton->hide();
+    allButton->setFlat(true);
+    runButton->setFocusPolicy ( Qt::NoFocus );
+    favButton->setFocusPolicy ( Qt::NoFocus );
+    allButton->setFocusPolicy ( Qt::NoFocus );
+    selectLayout=new QHBoxLayout();
+    selectLayout->addWidget(runButton);
+    selectLayout->addWidget(favButton);
+    selectLayout->addWidget(allButton);
     backButton=new QToolButton(parent->getCentralFrame());
     backButton->setIcon(QIcon( parent->iconsPath ( "/32x32/tbhide.png" )));
     backButton->setAutoRaise(true);
@@ -54,6 +71,14 @@ SessionExplorer::SessionExplorer(ONMainWindow* p):QObject(p)
 
     backButton->setPalette(pal);
     backButton->setAutoFillBackground(true);
+
+    runButton->setPalette(pal);
+    runButton->setAutoFillBackground(true);
+    favButton->setPalette(pal);
+    favButton->setAutoFillBackground(true);
+    allButton->setPalette(pal);
+    allButton->setAutoFillBackground(true);
+
     pal=pathLabel->palette();
     pal.setBrush ( QPalette::Window, QColor ( 110,112,127,255 ) );
     pal.setBrush ( QPalette::WindowText, QColor ( 200,200,200,255 ) );
@@ -61,12 +86,101 @@ SessionExplorer::SessionExplorer(ONMainWindow* p):QObject(p)
     pathLabel->setAutoFillBackground(true);
     setNavigationVisible(false);
     connect(backButton,SIGNAL(clicked(bool)), this, SLOT(slotLevelUp()));
+    connect(runButton,SIGNAL(clicked(bool)), this, SLOT(slotShowRun()));
+    connect(allButton,SIGNAL(clicked(bool)), this, SLOT(slotShowAll()));
+    connect(favButton,SIGNAL(clicked(bool)), this, SLOT(slotShowFav()));
 }
 
 SessionExplorer::~SessionExplorer()
 {
 }
 
+SessionButton * SessionExplorer::findSession(const QString& id)
+{
+    foreach (SessionButton* s, sessions)
+    {
+        if(s->id()==id)
+            return s;
+    }
+    return 0;
+}
+
+
+void SessionExplorer::updateSessions(QStringList slst)
+{
+    foreach (SessionButton* s, sessions)
+    {
+        s->setNotUpdated();
+    }
+    for ( int i=0; i<slst.size(); ++i )
+    {
+        if ( slst[i]=="embedded" )
+            continue;
+        SessionButton* s=findSession(slst[i]);
+        if(!s)
+        {
+            s=createBut ( slst[i] );
+        }
+        else
+            checkPath(s);
+        s->redraw();
+    }
+    foreach (SessionButton* s, sessions)
+    {
+        if(!s->isUpdated())
+        {
+            sessions.removeOne(s);
+            if(s==lastSession)
+            {
+                lastSession=0;
+                parent->slotCloseSelectDlg();
+                parent->slotClosePass();
+            }
+            delete s;
+        }
+    }
+    updateView();
+}
+
+void SessionExplorer::updateView()
+{
+    bool hasFavs=false;
+    bool hasRun=0;
+    foreach (SessionButton* s, sessions)
+    {
+        if(s->isFav())
+        {
+            hasFavs=true;
+        }
+        if(s->getRunning()||s->getSuspended())
+            hasRun=true;
+    }
+    runButton->setVisible(hasRun);
+    favButton->setVisible(hasFavs);
+    allButton->setVisible(hasRun||hasFavs);
+    if(initUpdate)
+    {
+        initUpdate=false;
+        if(hasRun)
+        {
+            viewMode=RUN;
+        }
+        else if(hasFavs)
+        {
+            viewMode=FAV;
+        }
+    }
+    if((!hasRun && viewMode==RUN)||(!hasFavs && viewMode==FAV))
+    {
+        viewMode=ALL;
+    }
+    allButton->setFlat(viewMode==ALL);
+    runButton->setFlat(viewMode==RUN);
+    favButton->setFlat(viewMode==FAV);
+
+    placeButtons();
+}
+
 void SessionExplorer::resize()
 {
     pathLabel->setMaximumWidth(parent->getUsersArea()->width()-backButton->width());
@@ -168,7 +282,7 @@ void SessionExplorer::slotCreateDesktopIcon ( SessionButton* bt )
 
 
     QString sessIcon = wrap_legacy_resource_URIs (st.setting ()->value (bt->id() + "/icon",
-                                                                        (QVariant) ":/img/icons/128x128/x2gosession.png"
+                                                                        (QVariant) parent->iconsPath("/128x128/x2gosession.png")
                                                                        ).toString ());
     sessIcon = expandHome(sessIcon);
     if ( sessIcon.startsWith ( ":/img/icons",Qt::CaseInsensitive ) ||
@@ -242,6 +356,17 @@ void SessionExplorer::slotCreateDesktopIcon ( SessionButton* bt )
 #endif
 }
 
+void SessionExplorer::checkPath(SessionButton* s)
+{
+    if(s->getPath()!="")
+    {
+        if(findFolder(s->getPath())==-1)
+        {
+            createFolder(s->getPath());
+        }
+    }
+}
+
 
 SessionButton* SessionExplorer::createBut ( const QString& id )
 {
@@ -256,14 +381,9 @@ SessionButton* SessionExplorer::createBut ( const QString& id )
 
     connect ( l,SIGNAL ( sessionSelected ( SessionButton* ) ),parent,
               SLOT ( slotSelectedFromList ( SessionButton* ) ) );
+    connect(l, SIGNAL( favClicked()), this, SLOT(updateView()));
 
-    if(l->getPath()!="")
-    {
-        if(findFolder(l->getPath())==-1)
-        {
-            createFolder(l->getPath());
-        }
-    }
+    checkPath(l);
 
     return l;
 }
@@ -271,9 +391,10 @@ SessionButton* SessionExplorer::createBut ( const QString& id )
 
 void SessionExplorer::placeButtons()
 {
+
     getFoldersFromConfig();
 
-    setNavigationVisible(currentPath.length()>0);
+    setNavigationVisible((currentPath.length()>0)&&(viewMode==ALL));
     resize();
     int currentVerticalPosition=0;
     qSort ( sessions.begin(),sessions.end(),SessionButton::lessThen );
@@ -281,7 +402,12 @@ void SessionExplorer::placeButtons()
 
     for ( int i=0; i<folders.size(); ++i )
     {
-        if(folders[i]->getPath() != currentPath)
+        if(viewMode!=ALL)
+        {
+            folders[i]->hide();
+            continue;
+        }
+        if((folders[i]->getPath() != currentPath)||(getFolderChildren(folders[i]).length()<=0) || isFolderEmpty(folders[i]))
         {
             folders[i]->hide();
             continue;
@@ -304,9 +430,25 @@ void SessionExplorer::placeButtons()
         folders[i]->setChildrenList(getFolderChildren(folders[i]));
     }
 
+    if(parent->isPassFormHidden() && parent->isSelectFormHidden())
+    {
+        lastSession=0;
+        parent->slotClosePass();
+    }
+
     for ( int i=0; i<sessions.size(); ++i )
     {
-        if(sessions[i]->getPath() != currentPath)
+        if((viewMode==ALL) && ( sessions[i]->getPath() != currentPath))
+        {
+            sessions[i]->hide();
+            continue;
+        }
+        if((viewMode==FAV) && (! sessions[i]->isFav()))
+        {
+            sessions[i]->hide();
+            continue;
+        }
+        if((viewMode==RUN) && (! (sessions[i]->getRunning() || sessions[i]->getSuspended())))
         {
             sessions[i]->hide();
             continue;
@@ -316,6 +458,7 @@ void SessionExplorer::placeButtons()
 
         sessions[i]->move ( horizontalPosition,
                             currentVerticalPosition+5 );
+        sessions[i]->showAdvInfo(viewMode!=ALL);
 
         if(parent->getBrokerMode())
         {
@@ -332,7 +475,12 @@ void SessionExplorer::placeButtons()
                 currentVerticalPosition+=230;
             }
         }
+//         x2goDebug<<"last session"<<(void*)lastSession<<"current"<<(void*)sessions[i];
         sessions[i]->show();
+        if(lastSession == sessions[i])
+        {
+            sessions[i]->hide();
+        }
     }
 
     if ( currentVerticalPosition )
@@ -340,8 +488,33 @@ void SessionExplorer::placeButtons()
         parent->getUsersFrame()->setFixedHeight (
             currentVerticalPosition);
     }
+    int id=findFolder(currentPath);
+    if(id<0)
+        return;
+    if(getFolderChildren(folders[id]).length()<=0)
+        slotLevelUp();
 }
 
+//Folder is not empty if it has sessions or not empty subfdolders
+bool SessionExplorer::isFolderEmpty(FolderButton* folder)
+{
+    QString normPath=(folder->getPath()+"/"+folder->getName()).split("/",QString::SkipEmptyParts).join("/");
+    for(int i=0; i<folders.count(); ++i)
+    {
+        if(folders[i]->getPath()==normPath)
+            if(! isFolderEmpty(folders[i]))
+                return false;
+    }
+
+    for(int i=0; i<sessions.count(); ++i)
+    {
+        if(sessions[i]->getPath()==normPath)
+            return false;
+    }
+    return true;
+}
+
+
 QStringList SessionExplorer::getFolderChildren(FolderButton* folder)
 {
     QStringList children;
@@ -388,6 +561,7 @@ void SessionExplorer::setNavigationVisible(bool value)
 
 void SessionExplorer::createFolder(QString path)
 {
+    x2goDebug<<"Create Folder:"<<path;
     QStringList tails=path.split("/");
     QStringList currentPath;
     for(int i=0; i<tails.count()-1; ++i)
@@ -617,4 +791,25 @@ void SessionExplorer::deleteFolder(QString path)
 void SessionExplorer::setEnable(bool enable)
 {
     backButton->setEnabled(enable);
+    runButton->setEnabled(enable);
+    favButton->setEnabled(enable);
+    allButton->setEnabled(enable);
+}
+
+void SessionExplorer::slotShowAll()
+{
+    viewMode=ALL;
+    updateView();
+}
+
+void SessionExplorer::slotShowRun()
+{
+    viewMode=RUN;
+    updateView();
+}
+
+void SessionExplorer::slotShowFav()
+{
+    viewMode=FAV;
+    updateView();
 }
