@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2020 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2023 by Oleksandr Shneyder                         *
 *                              <o.shneyder@phoca-gmbh.de>                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -26,6 +26,7 @@ class SessionButton;
 class FolderButton;
 class ONMainWindow;
 class QToolButton;
+class QPushButton;
 class QLabel;
 class QHBoxLayout;
 
@@ -57,12 +58,17 @@ public:
     {
         return navigationLayout;
     }
+    QHBoxLayout* getSelectLayout()
+    {
+        return selectLayout;
+    }
     bool isFolderEmpty(QString path);
     void resize();
     void setFolderIcon(QString path, QString icon);
     void createNewFolder(QString path);
     void renameFolder(QString oldPath, QString currentPath);
     void deleteFolder(QString path);
+    void updateSessions(QStringList slst);
 
     QString getCurrentPath()
     {
@@ -84,9 +90,15 @@ private:
     SessionButton* lastSession;
     ONMainWindow* parent;
     QToolButton* backButton;
+    QPushButton* favButton;
+    QPushButton* runButton;
+    QPushButton* allButton;
     QLabel* pathLabel;
     QHBoxLayout* navigationLayout;
+    QHBoxLayout* selectLayout;
     QString currentPath;
+    enum {ALL, FAV, RUN} viewMode;
+    bool initUpdate;
 
 //functions
 private:
@@ -94,6 +106,9 @@ private:
     int findFolder(QString path);
     void createFolder(QString path);
     void getFoldersFromConfig();
+    SessionButton* findSession( const QString& id);
+    void checkPath(SessionButton* s);
+    bool isFolderEmpty(FolderButton* folder);
 
 public slots:
     void slotDeleteButton ( SessionButton * bt );
@@ -104,6 +119,10 @@ private slots:
     void slotFolderSelected(FolderButton* bt);
     void slotLevelUp();
     QStringList getFolderChildren(FolderButton* folder);
+    void slotShowAll();
+    void slotShowRun();
+    void slotShowFav();
+    void updateView();
 };
 
 #endif
