@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2020 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2023 by Oleksandr Shneyder                         *
 *                              <o.shneyder@phoca-gmbh.de>                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -15,20 +15,21 @@
 *   along with this program.  If not, see <https://www.gnu.org/licenses/>. *
 ***************************************************************************/
 
-#ifndef _WIN32_WINDOWS
-#define _WIN32_WINDOWS 0x0500
-#define _WIN32_WINNT 0x0500
-#define WINVER 0x0500
-#endif
 #include "x2goclientconfig.h"
 #ifdef Q_OS_WIN
 #include <winsock2.h>
 #include <windows.h>
 #include <winerror.h>
 #include <sddl.h>
+#include <winnls.h>
+#include <AccCtrl.h>
+#include <aclapi.h>
 #include "wapi.h"
 #include "x2gologdebug.h"
 
+#if QT_VERSION > 0x050000
+#include <QtWin>
+#endif
 
 long wapiSetFSWindow ( HWND hWnd, const QRect& desktopGeometry )
 {
@@ -201,9 +202,23 @@ bool wapiMoveWindow ( HWND wnd, int x, int y, int width, int height,
     return MoveWindow ( wnd, x, y, width, height, repaint );
 }
 
-HWND wapiFindWindow ( const ushort * className, const ushort * text )
+HWND wapiFindWindow (const QString& text )
 {
-    return FindWindowEx ( 0,0, ( LPCTSTR ) className, ( LPCTSTR ) text );
+    HWND w=GetTopWindow(NULL);
+    char caption[512];
+    while (w)
+    {
+        if(GetWindowTextA(w, caption, 512))
+        {
+            QString c(caption);
+            if(c.indexOf(text)!=-1)
+            {
+                return w;
+            }
+        }
+        w=GetNextWindow(w,GW_HWNDNEXT);
+    }
+    return 0;
 }
 
 bool wapiSetWindowText( HWND wnd, const QString& text)
@@ -221,9 +236,13 @@ void wapiSetWindowIcon ( HWND wnd, const QPixmap& icon)
     HICON largeIcon=0;
     HICON smallIcon=0;
 
+#if QT_VERSION > 0x050000
+    largeIcon=QtWin::toHICON(icon.scaled(iconx,icony, Qt::IgnoreAspectRatio,Qt::SmoothTransformation));
+    smallIcon=QtWin::toHICON(icon.scaled(smallx,smally, Qt::IgnoreAspectRatio,Qt::SmoothTransformation));
+#else
     largeIcon=icon.scaled(iconx,icony, Qt::IgnoreAspectRatio,Qt::SmoothTransformation).toWinHICON ();
     smallIcon=icon.scaled(smallx,smally, Qt::IgnoreAspectRatio,Qt::SmoothTransformation).toWinHICON ();
-
+#endif
     x2goDebug<<"Large icon: "<<largeIcon<<iconx<<"x"<<icony;
     x2goDebug<<"Small icon: "<<smallIcon<<smallx<<"x"<<smally;
     int rez=SetClassLong(wnd,GCL_HICON, (LONG)largeIcon);
@@ -518,4 +537,96 @@ QString wapiGetUserName()
         return QString::null;
     return QString::fromUtf16 ( ( const ushort* ) infoBuf);
 }
+
+
+//copied this function from https://docs.microsoft.com/en-us/windows/win32/secauthz/modifying-the-acls-of-an-object-in-c--
+DWORD AddAceToObjectsSecurityDescriptor (
+    LPTSTR pszObjName,          // name of object
+    SE_OBJECT_TYPE ObjectType,  // type of object
+    LPTSTR pszTrustee,          // trustee for new ACE
+    TRUSTEE_FORM TrusteeForm,   // format of trustee structure
+    DWORD dwAccessRights,       // access mask for new ACE
+    ACCESS_MODE AccessMode,     // type of ACE
+    DWORD dwInheritance         // inheritance flags for new ACE
+)
+{
+    DWORD dwRes = 0;
+    PACL pOldDACL = NULL, pNewDACL = NULL;
+    PSECURITY_DESCRIPTOR pSD = NULL;
+    EXPLICIT_ACCESS ea;
+    if (NULL == pszObjName)
+        return ERROR_INVALID_PARAMETER;
+
+    // Get a pointer to the existing DACL.
+    dwRes = GetNamedSecurityInfo(pszObjName, ObjectType,
+                                 DACL_SECURITY_INFORMATION,
+                                 NULL, NULL, &pOldDACL, NULL, &pSD);
+    if (ERROR_SUCCESS != dwRes) {
+        goto Cleanup;
+    }
+    // Initialize an EXPLICIT_ACCESS structure for the new ACE.
+    ZeroMemory(&ea, sizeof(EXPLICIT_ACCESS));
+    ea.grfAccessPermissions = dwAccessRights;
+    ea.grfAccessMode = AccessMode;
+    ea.grfInheritance= dwInheritance;
+    ea.Trustee.TrusteeForm = TrusteeForm;
+    ea.Trustee.ptstrName = pszTrustee;
+    // Create a new ACL that merges the new ACE
+    // into the existing DACL.
+    dwRes = SetEntriesInAcl(1, &ea, pOldDACL, &pNewDACL);
+    if (ERROR_SUCCESS != dwRes)  {
+        goto Cleanup;
+    }
+
+    // Attach the new ACL as the object's DACL.
+    dwRes = SetNamedSecurityInfo(pszObjName, ObjectType,
+                                 DACL_SECURITY_INFORMATION,
+                                 NULL, NULL, pNewDACL, NULL);
+    if (ERROR_SUCCESS != dwRes)  {
+        goto Cleanup;
+    }
+Cleanup:
+    if(pSD != NULL)
+        LocalFree((HLOCAL) pSD);
+    if(pNewDACL != NULL)
+        LocalFree((HLOCAL) pNewDACL);
+    return dwRes;
+}
+
+void wapiSetFilePermissions(const QString& path)
+{
+    AddAceToObjectsSecurityDescriptor(
+        (wchar_t*) path.toStdWString().c_str(),
+        SE_FILE_OBJECT,
+        (wchar_t*) wapiGetUserName().toStdWString().c_str(),
+        TRUSTEE_IS_NAME,
+        ACCESS_SYSTEM_SECURITY | READ_CONTROL | WRITE_DAC | GENERIC_ALL,
+        GRANT_ACCESS,
+        CONTAINER_INHERIT_ACE);
+}
+
+QString wapiGetKeyboardLayout()
+{
+    wchar_t nm[LOCALE_NAME_MAX_LENGTH];
+    LCIDToLocaleName(HIWORD(GetKeyboardLayout(0)),nm,LOCALE_NAME_MAX_LENGTH,0);
+    QStringList l=QString::fromUtf16((char16_t*)nm).split("-");
+    if(l.count()==2)
+        return l[1].toLower();
+    return QString::null;
+}
+
+void wapiSetWinNotResizable(HWND wnd)
+{
+    SetWindowLong ( wnd, GWL_STYLE, GetWindowLong(wnd, GWL_STYLE)&~WS_SIZEBOX&~WS_MAXIMIZEBOX);
+}
+
+short wapiIsWinResizeable(HWND wnd)
+{
+    LONG flags=GetWindowLong(wnd, GWL_STYLE);
+    if(!flags)
+        return -1;
+    if((flags & WS_SIZEBOX) || (flags & WS_MAXIMIZEBOX))
+        return 1;
+    return 0;
+}
 #endif
