@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2020 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2023 by Oleksandr Shneyder                         *
 *                              <o.shneyder@phoca-gmbh.de>                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
 *   along with this program.  If not, see <https://www.gnu.org/licenses/>. *
 ***************************************************************************/
 #include <windows.h>
-#include <TlHelp32.h>
+#include <tlhelp32.h>
 void killProcess(DWORD pid)
 {
     HANDLE handle=OpenProcess(PROCESS_TERMINATE,0,pid);
